@@ -29,7 +29,6 @@ import java.util.StringTokenizer;
 import java.awt.*;
 import edu.xtec.jclic.Activity;
 import edu.xtec.util.StreamIO;
-import java.util.Vector;
 import java.util.Iterator;
 
 
@@ -67,22 +66,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
         popupsContent=new ActiveBagContent(1,1);
     }
     
-/*
-    public static void checkStyleContext(StyleContext sc){
-        Style targetStyle=sc.getStyle(TARGET);
-        if(targetStyle==null){            
-            targetStyle=sc.addStyle(TARGET, sc.getStyle(StyleContext.DEFAULT_STYLE));
-            StyleConstants.setForeground(targetStyle, DEFAULT_TARGET_COLOR);
-            targetStyle.addAttribute(TARGET, Boolean.TRUE);
-        }
-        Style targetErrorStyle=sc.getStyle(TARGET_ERROR);
-        if(targetErrorStyle==null){
-            targetErrorStyle=sc.addStyle(TARGET_ERROR, targetStyle);
-            StyleConstants.setForeground(targetErrorStyle, DEFAULT_TARGET_ERROR_COLOR);
-        }
-    }
- */
-    
     public static void checkStyleContext(StyleContext sc){
         Style targetStyle=sc.getStyle(TARGET);
         if(targetStyle==null){            
@@ -100,9 +83,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
     public void readClic3Data(Clic3Activity c3a, TextActivityBase tab) throws Exception{
         
         BoxBase bb=c3a.getBoxBase(0);
-        // changed
-        //tab.boxesContent.setBoxBase(c3a.getBoxBase(1));
-        //tab.popupsContent.setBoxBase(c3a.getBoxBase(3));
         boxesContent.setBoxBase(c3a.getBoxBase(1));
         popupsContent.setBoxBase(c3a.getBoxBase(3));
         
@@ -110,13 +90,10 @@ public class TextActivityDocument extends DefaultStyledDocument {
         
         setTabSpc(c3a.tabSpc);
         
-        //Style targetStyle=addStyle(TARGET, regular);
         Style targetStyle=getStyle(TARGET);
         StyleConstants.setBackground(targetStyle, c3a.colorUsuari[1]);
         StyleConstants.setForeground(targetStyle, c3a.colorUsuari[0]);
-        //targetStyle.addAttribute(TARGET, Boolean.TRUE);
         
-        //Style targetError=addStyle(TARGET_ERROR, targetStyle);
         Style targetError=getStyle(TARGET_ERROR);
         StyleConstants.setBackground(targetError, c3a.colorError[1]);
         StyleConstants.setForeground(targetError, c3a.colorError[0]);
@@ -191,20 +168,14 @@ public class TextActivityDocument extends DefaultStyledDocument {
                 
                 ab.userData=getEndPosition();
                 
-                //tab.boxesContent.addActiveBoxContent(ab);
                 boxesContent.addActiveBoxContent(ab);
                 
-                //JPanelActiveBox jpab=new JPanelActiveBox(tab.rb.getComponent());
                 JPanelActiveBox jpab=new JPanelActiveBox(null, null, tab.getProject().getBridge().getComponent());
                 jpab.setAlignmentY(0.9f);
                 jpab.setActiveBoxContent(ab);
                 MutableAttributeSet attr=new SimpleAttributeSet(regular);
                 StyleConstants.setComponent(attr, jpab);
                 insertString(getLength(), " ", attr);
-                //String styleName="box"+lastBoxId;
-                //Style boxStyle=addStyle(styleName, regular);
-                //StyleConstants.setComponent(boxStyle, jpab);
-                //insertString(getLength(), " ", boxStyle);
             }
             else if(intoTarget){
                 if(targetElementCount==0)
@@ -252,15 +223,12 @@ public class TextActivityDocument extends DefaultStyledDocument {
                             tm.target.popupContent.setDimension(new Dimension(w, h));
                             c3a.setActiveBoxTextContent(tm.target.popupContent, t);
                             
-                            //tm.target.popupContent.setBoxBase(tab.popupsContent.bb);
                             tm.target.popupContent.setBoxBase(popupsContent.bb);
                             
                             tm.target.popupContent.txtAlign[0]=leftAlign ? JDomUtility.ALIGN_LEFT : JDomUtility.ALIGN_MIDDLE;
                             tm.target.popupContent.imgAlign[0]=tm.target.popupContent.txtAlign[0];
-                            //tm.target.popupContent.userData=new Boolean(onlyPlay);
                             tm.target.onlyPlay=onlyPlay;
                             
-                            //tab.popupsContent.addActiveBoxContent(tm.target.popupContent);
                             popupsContent.addActiveBoxContent(tm.target.popupContent);
                         }
                         break;
@@ -270,9 +238,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
                 }
             }
             else{
-                //insertString(getLength(), t, getStyle("regular"));
                 insertString(getLength(), t, getStyle(StyleContext.DEFAULT_STYLE));
-                //insertString(getLength(), edu.xtec.jclic.utility.Utils.replace(t, "\n\r", "\n"), getStyle(DEFAULT));
             }
         }
         tmb.setPositions();
@@ -295,9 +261,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
         StyleConstants.setComponent(satr, jpab);
         doc.insertString(atPos, " ", satr);
         return jpab;
-        
-        //ab.userData=atPos;
-                
     }
     
     public static Style boxBaseToStyledDocument(BoxBase bb, StyledDocument sd){
@@ -335,13 +298,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
         MutableAttributeSet atr=new SimpleAttributeSet();
         atr.setResolveParent(style!=null ? style : a);
         
-        /*
-        if(parentStyle!=null)
-            a=new SimpleAttributeSet(doc.getStyle(parentStyle));
-        else
-            a=new SimpleAttributeSet(a);
-         */
-        
         fillAttributes(atr, e);
         
         return atr;
@@ -388,14 +344,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
             s=doc.addStyle(styleName, base);
         }
         
-        /*
-        if(styleName.equals(StyleContext.DEFAULT_STYLE)){
-            s=doc.getStyle(styleName);
-        } else{
-            s=doc.addStyle(styleName, doc.getStyle(JDomUtility.getStringAttr(e, BASE, StyleContext.DEFAULT_STYLE, false)));
-        }
-         */
-        
         fillAttributes(s, e);
     }
     
@@ -573,7 +521,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
         
         if(elementName.equals("component")){
             Object cmp=atr.getAttribute(StyleConstants.ComponentAttribute);
-            //if(cmp!=null && cmp.getClass().isAssignableFrom(JPanelActiveBox.class)){
             if(cmp!=null && cmp instanceof JPanelActiveBox){
                 JPanelActiveBox jpab=(JPanelActiveBox)cmp;
                 return jpab.getActiveBox().getContent().getJDomElement();
@@ -597,14 +544,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
         
         e=new org.jdom.Element(elementName);
         
-        /*
-        if(style==null || atr.getAttributeCount()>0){
-            exploreJDomElementAttributes(e, atr);
-        } else{
-            if(!StyleContext.DEFAULT_STYLE.equals(style) && !TARGET.equals(style))
-                e.setAttribute(STYLE, style);
-        }
-         */
         if(style==null || !atr.isEqual(getStyle(style))){
             setJDomElementAttributes(e, atr, elementName.equals(P));
         } else{
@@ -619,8 +558,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
                 e.setText(getElementText(element));
             else{
                 if(elementName.equals(TEXT)) return null;
-            }
-            
+            }            
         } else{
             for(int i=0; i<count; i++){
                 org.jdom.Element child=getJDomElement(element.getElement(i));
@@ -639,21 +577,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
             s=element.getDocument().getText(offset, length);
         return edu.xtec.util.StrUtils.replace(s, "\n", "");
     }
-    
-    /*
-    protected static void exploreJDomElementAttributes(org.jdom.Element e, AttributeSet atr){
-        String styleName=(String)atr.getAttribute(AttributeSet.NameAttribute);
-     
-        if(styleName!=null){
-            e.setAttribute(STYLE, styleName);
-        } else{
-            AttributeSet parent=(AttributeSet)atr.getAttribute(AttributeSet.ResolveAttribute);
-            if(parent!=null)
-                setJDomElementAttributes(e, parent);
-        }
-    }
-     */
-    
+        
     protected static void setJDomElementAttributes(org.jdom.Element e, AttributeSet atr, boolean isParagraph){
         java.util.Enumeration atrNames=atr.getAttributeNames();
         if(atrNames!=null){
@@ -710,12 +634,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
             String elementName=e.getName();
             if(elementName.equals(P)){
                 int p=doc.getLength();
-                //String parentName=e.getAttributeValue(STYLE);
-                //if(parentName!=null){
-                //    atr=new SimpleAttributeSet(doc.getStyle(parentName));
-                //    fillAttributes(atr, e);
-                //    p=doc.getLength();
-                //}
                 atr=getAttributes(doc, atrBase, e);
                 processChilds(e.getChildren(), doc, tab, atr);
                 if(i<childs.size()-1)
@@ -724,15 +642,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
                 doc.setParagraphAttributes(p, doc.getLength()-p, atr, true);
             }
             else if(elementName.equals(TEXT)){
-                //String parentName=e.getAttributeValue(STYLE);
-                //if(parentName!=null){
-                //    atr=new SimpleAttributeSet(doc.getStyle(parentName));
-                //    fillAttributes(atr, e);
-                //}
-                
-                //processChilds(e.getChildren(), doc, tab, atr);
-                
-                //doc.insertString(doc.getLength(), e.getText(), atr);
                 doc.insertString(doc.getLength(), e.getText(), getAttributes(doc, atrBase, e));
             }
             else if(elementName.equals(TARGET)){
@@ -764,36 +673,6 @@ public class TextActivityDocument extends DefaultStyledDocument {
         }
     }
     
-    /*
-    public static void listReferences(org.jdom.Element e, java.util.HashMap map){
-        java.util.Iterator it=e.getChildren(ActiveBoxContent.ELEMENT_NAME).iterator();
-        while(it.hasNext())
-            ActiveBoxContent.listReferences((org.jdom.Element)it.next(), map);
-        
-        it=e.getChildren().iterator();
-        while(it.hasNext()){
-            org.jdom.Element child=(org.jdom.Element)it.next();
-            if(!ActiveBoxContent.ELEMENT_NAME.equals(child.getName()))
-                listReferences(child, map);
-        }
-    }
-     */
-    
-    /*
-    public static void nameChanged(org.jdom.Element e, String type, String oldName, String newName){
-        java.util.Iterator it=e.getChildren(ActiveBoxContent.ELEMENT_NAME).iterator();
-        while(it.hasNext())
-            ActiveBoxContent.nameChanged((org.jdom.Element)it.next(), type, oldName, newName);
-     
-        it=e.getChildren().iterator();
-        while(it.hasNext()){
-            org.jdom.Element child=(org.jdom.Element)it.next();
-            if(!ActiveBoxContent.ELEMENT_NAME.equals(child.getName()))
-                nameChanged(child, type, oldName, newName);
-        }
-    }
-     */
-    
     public TextActivityDocument cloneDoc(TextActivityDocument dest, boolean hideTargets, boolean initTargets, boolean hideTargetStyle) throws Exception{
         tmb.updateOffsets();
         TextActivityDocument d=dest;
@@ -892,83 +771,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
         d.tmb.setPositions();
         return d;
     }
-    
-    /*
-    public TextActivityDocument cloneDocBak(TextActivityDocument dest, boolean hideTargets, boolean initTargets, boolean hideTargetStyle) throws Exception{
-        tmb.updateOffsets();
-        TextActivityDocument d=dest;
-        if(d==null)
-            d=new TextActivityDocument(styleContext);
-        AttributeSet s, s2;
-        s=getStyle(StyleContext.DEFAULT_STYLE);
-        s2=null;
-        d.setParagraphAttributes(0, d.getLength(), s, true);
-        d.boxesContent=boxesContent;
-        d.popupsContent=popupsContent;
-        TargetMarker tm=null;
-        TargetMarker tmx=null;
-        MutableAttributeSet attr=null;
-        String si=null;
-        int i=0;
-        int j=0;
-        int l=getLength();
-        s=getCharacterElement(0).getAttributes();
-        while(i<l){
-            for(j=i+1; j<l; j++){
-                s2=getCharacterElement(j).getAttributes();
-                if(!s.isEqual(s2)) break;
-            }
-            attr=null;
-            si=null;
-            tm=tmb.getElementByOffset(i, false);
-            if(tm!=null){
-                tmx=new TargetMarker(d);
-                tmx.begOffset=d.getLength();
-                tmx.target=tm.target;
-                if(tm.target!=null && initTargets){
-                    if(tm.target.isList){
-                        attr=new SimpleAttributeSet(s);
-                        StyleConstants.setComponent(attr, tm.target.buildCombo(s, getStyle(TARGET_ERROR)));
-                        si=" ";
-                    } else{
-                        if(tm.target.iniText!=null){
-                            si=tm.target.iniText;
-                        } else{
-                            si=tm.target.getFillString();
-                            attr=new SimpleAttributeSet(s);
-                            attr.addAttribute(FILL, Boolean.TRUE);
-                        }
-                    }
-                }
-                else if(hideTargets){
-                    si=new String();
-                }
-                else if(hideTargetStyle){
-                    attr=styleContext.getStyle(StyleContext.DEFAULT_STYLE);
-                }
-            }
-            if(si==null){
-                try{
-                    si=getText(i, j-i);
-                } catch(Exception e){}
-            }
-     
-            if(si!=null && si.length()>0){
-                d.insertString(d.getLength(), si, attr!=null ? attr : s);
-            }
-     
-            if(tm!=null){
-                tmx.endOffset=d.getLength();
-                d.tmb.add(tmx);
-            }
-            i=j;
-            s=s2;
-        }
-        d.tmb.setPositions();
-        return d;
-    }
-     */
-    
+        
     public static Font attributesToFont(AttributeSet s){
         int style=(StyleConstants.isBold(s) ? Font.BOLD : 0) | (StyleConstants.isItalic(s) ? Font.ITALIC : 0);
         return new Font(StyleConstants.getFontFamily(s), style ,StyleConstants.getFontSize(s));
@@ -1038,6 +841,32 @@ public class TextActivityDocument extends DefaultStyledDocument {
             it.remove();
         }
     }
+
+    public org.jdom.Element getJDomElementWithoutStyles() throws Exception{
+        org.jdom.Element mainElement=getJDomElement();
+        clearElementStyles(mainElement);
+        return mainElement;
+    }
+
+    protected void clearElementStyles(org.jdom.Element e) {
+        String s=e.getName();
+        if(P.equals(s) || TEXT.equals(s)){
+            Iterator it=e.getAttributes().iterator();
+            java.util.HashSet set=new java.util.HashSet();
+            while(it.hasNext()){
+                org.jdom.Attribute at=(org.jdom.Attribute)it.next();
+                if(!TEXT.equals(at.getName()))
+                    set.add(at);
+            }
+            it=set.iterator();
+            while(it.hasNext())
+                e.removeAttribute((org.jdom.Attribute)it.next());
+        }
+        Iterator it=e.getChildren().iterator();
+        while(it.hasNext())
+            clearElementStyles((org.jdom.Element)it.next());
+    }
+
     
     /** Getter for property targetType.
      * @return Value of property targetType.
