@@ -24,17 +24,20 @@ package edu.xtec.jclic.bags;
 import edu.xtec.jclic.Constants;
 import edu.xtec.jclic.edit.*;
 import edu.xtec.util.Options;
+import edu.xtec.util.StrUtils;
 import java.awt.Component;
 import edu.xtec.jclic.misc.Utils;
 import edu.xtec.jclic.fileSystem.FileSystem;
 import edu.xtec.jclic.fileSystem.ZipFileSystem;
 import edu.xtec.jclic.project.JClicProjectEditor;
 import edu.xtec.util.Messages;
-import edu.xtec.util.NarrowOptionPane;
 import edu.xtec.util.ProgressDialog;
 import edu.xtec.util.StreamIO;
 import edu.xtec.util.SwingWorker;
+import java.awt.Color;
+import java.awt.Cursor;
 import java.awt.Image;
+import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -43,6 +46,7 @@ import java.util.Iterator;
 import java.util.Vector;
 import javax.swing.Icon;
 import javax.swing.JComponent;
+import javax.swing.SwingUtilities;
 
 /**
  *
@@ -50,12 +54,19 @@ import javax.swing.JComponent;
  * @version 1.0
  */
 public class MediaBagEditor extends Editor{
-    
+
+    public static final int DEFAULT_IMG_MAX_WIDTH=800;
+    public static final int DEFAULT_IMG_MAX_HEIGHT=600;
+    public static final int IMG_MIN_SIZE=10;
+    public static final String RESIZED="resized";
+
     //public static EditorAction newMediaAction;
     public static boolean actionsCreated;
     private boolean initializing;
     public static EditorAction newMediaBagElementAction, updateAllMediaAction, exportAllMediaAction;
     private static Icon icon;
+    protected static int imgMaxWidth=DEFAULT_IMG_MAX_WIDTH;
+    protected static int imgMaxHeight=DEFAULT_IMG_MAX_HEIGHT;
     
     /** Creates a new instance of MediaBagEditor */
     public MediaBagEditor(MediaBag mb) {
@@ -136,6 +147,7 @@ public class MediaBagEditor extends Editor{
         MediaBagElementEditor[] result=null;
         Messages msg=options.getMessages();
         MediaBag mb=getMediaBag();
+        FileSystem fs=mb.getProject().getFileSystem();
         String[] fNames=selectMediaFiles(getMediaBag(), options, dlgOwner, fileFilters, null);
         if(fNames!=null){
             Vector v=new Vector();
@@ -149,7 +161,75 @@ public class MediaBagEditor extends Editor{
                 }
                 else{
                     MediaBagElement mbe=new MediaBagElement(fNames[i], null, getValidMediaName(fNames[i]));
-                    if(mb.addElement(mbe)){
+                    boolean cancel=false;
+
+                    // Check image size
+                    if(mbe.isImage()){
+                        Image img=null;
+                        try {
+                            img=mbe.prepareAndGetImage(fs);
+                            if(img==null)
+                                throw new Exception("invalid image!");
+                        } catch (Exception ex){
+                            msg.showErrorWarning(dlgOwner, "err_reading_data", fNames[i], ex, null);
+                            cancel=true;
+                        }
+
+                        if (img != null) {
+                            int imgWidth = img.getWidth(null);
+                            int imgHeight = img.getHeight(null);
+
+                            if ((imgWidth > imgMaxWidth || imgHeight > imgMaxHeight)) {
+                                int answer = msg.showQuestionDlgObj(
+                                        dlgOwner,
+                                        new String[]{StrUtils.replace(
+                                            msg.get("img_resize_prompt"),
+                                            "%s",
+                                            new String[]{
+                                                fNames[i],
+                                                "" + imgWidth + "x" + imgHeight,
+                                                "" + imgMaxWidth + "x" + imgMaxHeight
+                                            })},
+                                        "CONFIRM",
+                                        "ync");
+
+                                if (answer == Messages.CANCEL) {
+                                    cancel = true;
+                                } else if (answer == Messages.YES) {
+
+                                    // TODO: Process can be long. Display wait cursor
+
+                                    String baseName = fNames[i];
+                                    int lastDot = baseName.lastIndexOf(".");
+                                    if (lastDot > 0) {
+                                        baseName = baseName.substring(0, lastDot);
+                                    }
+
+                                    String newName = baseName + "-" + RESIZED + ".jpg";
+                                    File destFile = new File(fs.getFullFileNamePath(newName));
+                                    int counter = 0;
+                                    while (destFile.exists()) {
+                                        newName = baseName + "-" + RESIZED + Integer.toString(++counter) + ".jpg";
+                                        destFile = new File(fs.getFullFileNamePath(newName));
+                                    }
+
+                                    try {
+                                        javax.swing.ImageIcon resizedImg = mbe.getThumbNail(imgMaxWidth, imgMaxHeight, fs);
+                                        BufferedImage bimg=Utils.toBufferedImage(resizedImg.getImage(), Color.white, null);
+                                        javax.imageio.ImageIO.write(bimg, "jpg", destFile);
+                                        fNames[i] = newName;
+                                        mbe = new MediaBagElement(fNames[i], null, getValidMediaName(fNames[i]));
+                                    } catch (Exception ex) {
+                                        cancel=true;
+                                        msg.showErrorWarning(dlgOwner, "err_file_save", ex);
+                                    }
+
+                                }
+                            }
+                        }
+                    }
+
+                    if(!cancel && mb.addElement(mbe)){
                         v.add(mbe.getEditor(this));
                         //fireEditorDataChanged(null);
                     }
@@ -419,5 +499,21 @@ public class MediaBagEditor extends Editor{
         }
         return result;
     }
+
+    public static int getImgMaxWidth(){
+        return imgMaxWidth;
+    }
+
+    public static void setImgMaxWidth(int width){
+        imgMaxWidth=Math.max(IMG_MIN_SIZE, width);
+    }
+
+    public static int getImgMaxHeight(){
+        return imgMaxHeight;
+    }
+
+    public static void setImgMaxHeight(int height){
+        imgMaxHeight=Math.max(IMG_MIN_SIZE, height);
+    }
     
 }
