@@ -23,6 +23,7 @@ package edu.xtec.jclic;
 
 import edu.xtec.jclic.automation.AutoContentProvider;
 import edu.xtec.jclic.bags.MediaBagElement;
+import edu.xtec.jclic.boxes.AbstractBox;
 import edu.xtec.jclic.boxes.ActiveBagContent;
 import edu.xtec.jclic.boxes.ActiveBoxBag;
 import edu.xtec.jclic.boxes.ActiveBoxContent;
@@ -49,8 +50,10 @@ import java.awt.Image;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
+import java.awt.Robot;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
+import java.awt.geom.Point2D;
 import java.lang.reflect.Constructor;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -894,9 +897,6 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     
     public abstract class Panel extends JPanel {
         
-        //public Activity act;
-        //public ActivityContainer ac;
-        
         public Skin skin=null;
         public boolean solved=false;
         public Image bgImage=null;
@@ -906,6 +906,11 @@ public abstract class Activity extends Object implements Constants, Editable, Do
         protected BoxConnector bc=null;
         public PlayStation ps;
         
+        /*
+         *Object that currently has the focus of user interaction
+         */
+        protected Object focusedItem=null;
+        
         /** Creates new ActivityPanel */
         protected Panel(PlayStation ps) {
             super();
@@ -921,8 +926,35 @@ public abstract class Activity extends Object implements Constants, Editable, Do
             
             // 02-oct-2006: Added a call to initAutoContentProvider
             initAutoContentProvider();
+            
+            //setFocusCycleRoot(false);
+            //setFocusTraversalPolicy(ftp);
+            
         }
         
+        /*
+        FocusTraversalPolicy ftp=new FocusTraversalPolicy(){
+            public Component getComponentAfter(Container focusCycleRoot, Component aComponent){
+                return Panel.this;
+            }
+            public Component getComponentBefore(Container focusCycleRoot, Component aComponent){
+                return Panel.this;
+            }
+            public Component getDefaultComponent(Container focusCycleRoot){
+                return Panel.this;
+            }
+            public Component getFirstComponent(Container focusCycleRoot){
+                return Panel.this;
+            }
+            public Component getInitialComponent(Window window){
+                return Panel.this;
+            }
+            public Component getLastComponent(Container focusCycleRoot){
+                return Panel.this;
+            }
+        };  
+         */
+        
         public Activity getActivity(){
             return Activity.this;
         }
@@ -1131,6 +1163,52 @@ public abstract class Activity extends Object implements Constants, Editable, Do
             super.processEvent(e);
         }
         
+        /**
+         * Getter for property focusedItem.
+         * @return Value of property focusedItem.
+         */
+        public Object getFocusedItem() {
+            return focusedItem;
+        }
+        
+        /**
+         * Setter for property focusedItem.
+         * @param focusedItem New value of property focusedItem.
+         */
+        public void setFocusedItem(Object focusedItem) {
+            unmarkFocusedItem();
+            this.focusedItem = focusedItem;
+            if(this.focusedItem!=null && focusedItem instanceof AbstractBox && ps.isFocusedItemMarked()){
+                AbstractBox bx=(AbstractBox)focusedItem;
+                bx.setFocused(true);                                
+                Robot robot=ps.getRobot();
+                if(robot!=null){
+                    Point2D pt=bx.getAbsoulteMiddleLocation();
+                    if(pt!=null){
+                        robot.mouseMove((int)pt.getX(), (int)pt.getY());
+                    }
+                }
+            }            
+        }
+        
+        /* Removes the visual marker of the currently focused item
+         */
+        public void unmarkFocusedItem(){
+            if(focusedItem!=null && focusedItem instanceof AbstractBox && ps.isFocusedItemMarked()){
+                ((AbstractBox)focusedItem).setFocused(false);                
+            }
+        }
+                
+        /* Moves the internal focus of user's interaction to the next element.
+         * default implementation does nothing.
+         * @return Object focused when the operation completes, or <CODE>null</CODE> if
+         * there are no more objects to be focused.
+         */
+        public Object nextFocusedItem(){
+            setFocusedItem(null);
+            return focusedItem;
+        }
+        
     }
     
 }
