@@ -901,7 +901,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                 actPanel.forceFinishActivity();
                 stopMedia();
                 activeMediaBag.removeAll();
-                if(Runtime.getRuntime().freeMemory()<0x100000L){
+                if(Utils.lowMemoryCondition()){
                     if(trace)
                         System.out.println(">>> LOW MEMORY! cleaning...");
                     project.mediaBag.clearData();
