@@ -514,9 +514,14 @@ public class ActiveBox extends AbstractBox implements Cloneable {
                      : abc.txtAlign[0]==JDomUtility.ALIGN_RIGHT 
                        ? ww-wtl 
                        : (ww-wtl)/2);
-                if(!layout.isLeftToRight()){
-                    dx-=wtl;
-                }
+
+                // 21-dec-1009
+                // Removed: right-to-left writting is automatically computed
+                // by TextLayout!
+                //
+                //if(!layout.isLeftToRight()){
+                //    dx-=wtl;
+                //}
                 h+=layout.getAscent();
                 if(bb.shadow){
                     g2.setColor(bb.shadowColor);
