@@ -21,8 +21,6 @@
 
 package edu.xtec.jclic.report.servlet;
 
-import javax.servlet.*;
-import javax.servlet.http.*;
 import edu.xtec.servlet.*;
 
 /**
