@@ -37,7 +37,6 @@ import java.util.Iterator;
 import javax.swing.JComponent;
 import java.awt.GridBagLayout;
 import java.awt.GridBagConstraints;
-import javax.swing.BoxLayout;
 import javax.swing.JButton;
 import javax.swing.JPanel;
 import javax.swing.JLabel;
@@ -366,8 +365,12 @@ public class Messages {
     }
     
     public boolean showInputDlg(Component parent, JComponent mainComponent, String titleKey, String buttons){
+        return showInputDlg(parent, mainComponent, titleKey, buttons, false);
+    }
+
+    public boolean showInputDlg(Component parent, JComponent mainComponent, String titleKey, String buttons, boolean centerOnParent){
         
-        InputDlg dlg=new InputDlg(parent, titleKey, buttons, mainComponent);
+        InputDlg dlg=new InputDlg(parent, titleKey, buttons, mainComponent, centerOnParent);
         return dlg.getFeedback()==OK;        
         
         //String title= (titleKey!=null ? get(titleKey) : "");        
@@ -378,7 +381,9 @@ public class Messages {
     class InputDlg extends JDialog implements java.awt.event.ActionListener{
         int result=CANCEL;
         Component parent;
-        InputDlg(Component parent, String titleKey, String buttons, JComponent mainComponent){
+        boolean centerOnParent;
+
+        InputDlg(Component parent, String titleKey, String buttons, JComponent mainComponent, boolean centerOnParent){
             // 26-jan-06 - Modified to solve bug #73, reported by Jorda Polo
             // Compile error in gcj 4.0.3:
             // "Can't reference 'this' before the superclass constructor has been called."
@@ -394,6 +399,8 @@ public class Messages {
             // --------
             
             this.parent=parent;
+            this.centerOnParent=centerOnParent;
+
             setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
             getContentPane().setLayout(new BorderLayout(10, 10));
             if(mainComponent!=null)
@@ -426,10 +433,14 @@ public class Messages {
             }
         }        
         public int getFeedback(){
-            pack();            
-            if(parent!=null)
-                setLocation((parent.getWidth()-getWidth())/2, (parent.getHeight()-getHeight())/2);
-            setLocationRelativeTo(parent);        
+            pack();
+            Component cmp=centerOnParent ? parent : JOptionPane.getFrameForComponent(parent);
+            if(cmp!=null){
+                int pw=cmp.getWidth();
+                int ph=cmp.getHeight();
+                setLocation((pw-getWidth())/2, (ph-getHeight())/2);
+                setLocationRelativeTo(cmp);
+            }
             if(!showDlg(this))
                 result=CANCEL;
             return result;            
